@@ -1,9 +1,13 @@
 import click
-from py42.exceptions import Py42NotFoundError
+from py42.services.detectionlists.departing_employee import DepartingEmployeeFilters
 
 from code42cli.bulk import generate_template_cmd_factory
 from code42cli.bulk import run_bulk_process
 from code42cli.click_ext.groups import OrderedGroup
+from code42cli.cmds.detectionlists import ALL_FILTER
+from code42cli.cmds.detectionlists import get_choices
+from code42cli.cmds.detectionlists import handle_filter_choice
+from code42cli.cmds.detectionlists import list_employees
 from code42cli.cmds.detectionlists import update_user
 from code42cli.cmds.detectionlists.options import cloud_alias_option
 from code42cli.cmds.detectionlists.options import notes_option
@@ -12,10 +16,23 @@ from code42cli.cmds.shared import get_user_id
 from code42cli.errors import Code42CLIError
 from code42cli.file_readers import read_csv_arg
 from code42cli.file_readers import read_flat_file_arg
+from code42cli.options import format_option
 from code42cli.options import sdk_options
 
 
+def _get_filter_choices():
+    filters = DepartingEmployeeFilters.choices()
+    return get_choices(filters)
+
+
 DATE_FORMAT = "%Y-%m-%d"
+filter_option = click.option(
+    "--filter",
+    help="Departing employee filter options. Defaults to {}.".format(ALL_FILTER),
+    type=click.Choice(_get_filter_choices()),
+    default=ALL_FILTER,
+    callback=lambda ctx, param, arg: handle_filter_choice(arg),
+)
 
 
 @click.group(cls=OrderedGroup)
@@ -25,6 +42,18 @@ def departing_employee(state):
     pass
 
 
+@departing_employee.command("list")
+@sdk_options()
+@format_option
+@filter_option
+def _list(state, format, filter):
+    """Lists the employees on the Departing Employee list."""
+    employee_generator = _get_departing_employees(state.sdk, filter)
+    list_employees(
+        employee_generator, format, {"departureDate": "Departure Date"},
+    )
+
+
 @departing_employee.command()
 @username_arg
 @click.option(
@@ -47,14 +76,7 @@ def add(state, username, cloud_alias, departure_date, notes):
 @sdk_options()
 def remove(state, username):
     """Remove a user from the departing-employee detection list."""
-    try:
-        _remove_departing_employee(state.sdk, username)
-    except Py42NotFoundError:
-        raise Code42CLIError(
-            "User {} is not currently on the departing-employee detection list.".format(
-                username
-            )
-        )
+    _remove_departing_employee(state.sdk, username)
 
 
 @departing_employee.group(cls=OrderedGroup)
@@ -128,6 +150,10 @@ def bulk_remove(state, file_rows):
     )
 
 
+def _get_departing_employees(sdk, filter):
+    return sdk.detectionlists.departing_employee.get_all(filter)
+
+
 def _add_departing_employee(sdk, username, cloud_alias, departure_date, notes):
     user_id = get_user_id(sdk, username)
     sdk.detectionlists.departing_employee.add(user_id, departure_date)
